﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;


using System.Windows.Threading;

namespace PythonIDE.ColorText {
    /// <summary>
    /// Interaction logic for FShowColorText.xaml
    /// </summary>
    public partial class WShowColorText : Window {

        String dialogname = "WShowColorText";

        static String fontname1 = "Courier New";
        static String fontname = "Consolas";

        MyColorTextBox mycolortextbox = null;

        private int mainfontsize;

        IParentColorText parentColor = null;

        private Typeface typefaceNormal = new Typeface(new FontFamily(fontname), FontStyles.Normal, FontWeights.Normal, FontStretches.Normal);
        private Typeface typefaceSemiBold = new Typeface(new FontFamily(fontname), FontStyles.Normal, FontWeights.SemiBold, FontStretches.Normal);

        private DispatcherTimer dispatcherTimer = new DispatcherTimer();

        public WShowColorText(Window parent, MyTextBox edit) {
            InitializeComponent();
            this.Owner = parent;  // Important, because CenterOwner    
            this.WindowStartupLocation = WindowStartupLocation.CenterOwner;
            parentColor = (IParentColorText)parent;
            //mycolortextbox2 = new MyColorTextBox2(edit.getModell());
            mycolortextbox = new MyColorTextBox(edit);
        }

        private void Window_Loaded(Object sender, RoutedEventArgs e) {
            colorpanel.Children.Add(mycolortextbox);
            Basis.setWindowPositionFromRegistry(this, SingVar.C_REG_ADR, dialogname);
            this.mainfontsize = Basis.ReadRegInt(SingVar.C_REG_ADR, "fontcolorsize");
            if (mainfontsize == 0) {
                mainfontsize = 14;
            }
            //setFontsize(mainfontsize);
            setFontsizeRegistry(mainfontsize);
            setTabsize();

            setFontweights();
            dispatcherTimer.Tick += new EventHandler(dispatcherTimer_Tick);
            dispatcherTimer.Interval = TimeSpan.FromMilliseconds(500);
            dispatcherTimer.Stop();

        }

        private void dispatcherTimer_Tick(object sender, EventArgs e) {
            dispatcherTimer.Stop();
            CommandManager.InvalidateRequerySuggested();
            setFontweights();
        }



        private void setFontweights() {
            String tab = Basis.ReadRegString(SingVar.C_REG_ADR, "fontweight");
            if (tab.Equals("NormalSemiBold")) {
                mnFontweightsNormalSemiBold_Click(mnFontweightsNormalSemiBold, null);
            }
            else if (tab.Equals("NormalNormal")) {
                mnFontweightsNormalNormal_Click(mnFontweightsNormalNormal, null);
            }
            else {
                //NormalNormal
                mnFontweightsNormalSemiBold_Click(mnFontweightsNormalSemiBold, null);
            }
        }

        public void setTabsize() {
            String tab = Basis.ReadRegString(SingVar.C_REG_ADR, "tabsize");
            if (tab.Length > 0) {
                if (tab.Equals("0.5")) {
                    mnSize05.IsChecked = true;
                    mycolortextbox.setTabsize(0.5);
                }
                if (tab.Equals("1.0")) {
                    mnSize10.IsChecked = true;
                    mycolortextbox.setTabsize(1.0);
                }
                if (tab.Equals("1.5")) {
                    mnSize15.IsChecked = true;
                    mycolortextbox.setTabsize(1.5);
                }
                if (tab.Equals("2.0")) {
                    mnSize20.IsChecked = true;
                    mycolortextbox.setTabsize(2.0);
                }
                if (tab.Equals("2.5")) {
                    mnSize25.IsChecked = true;
                    mycolortextbox.setTabsize(2.5);
                }
                if (tab.Equals("3.0")) {
                    mnSize30.IsChecked = true;
                    mycolortextbox.setTabsize(3.0);
                }
            }
        }


        public void colorChanged() {
            mycolortextbox.colorChanged();
        }

        public void setEdit(MyTextBox edit) {
            mycolortextbox.setModell(edit);
        }

        private void Window_SizeChanged(Object sender, SizeChangedEventArgs e) {
            //  mycolortextbox2.setSize(mainMenu.ActualWidth, mainMenu.ActualHeight);
        }

        private void scrollviewer_SizeChanged(Object sender, SizeChangedEventArgs e) {
            // mycolortextbox.setSize(scrollviewer.ActualWidth);
        }


        private void Window_KeyDown(Object sender, KeyEventArgs e) {
            // KeyDown="Window_KeyDown"    
            mycolortextbox.MyColorTextBox_Window_KeyDown(sender, e);
        }

        private void setFontWeightMenues(MenuItem mn) {
            mnFontweightsNormalNormal.IsChecked = false;
            mnFontweightsNormalSemiBold.IsChecked = false;
            mn.IsChecked = true;
        }


        /*
          typefaceThin
typefaceExtraLight
typefaceLight
typefaceNormal
typefaceMedium
typefaceSemiBold
typefaceBold
typefaceExtraBold
typefaceBlack
typefaceExtraBlack
*/



        private void mnFontweightsNormalNormal_Click(Object sender, RoutedEventArgs e) {
            setFontWeightMenues((MenuItem)sender);
            mycolortextbox.setTypeFaces(typefaceNormal, typefaceNormal);
            Basis.WriteRegString(SingVar.C_REG_ADR, "fontweight", "NormalNormal");
        }

        private void mnFontweightsNormalSemiBold_Click(Object sender, RoutedEventArgs e) {
            setFontWeightMenues((MenuItem)sender);
            mycolortextbox.setTypeFaces(typefaceNormal, typefaceSemiBold);
            Basis.WriteRegString(SingVar.C_REG_ADR, "fontweight", "NormalSemiBold");
        }



        private void Window_PreviewMouseWheel(Object sender, MouseWheelEventArgs e) {
            if (Keyboard.Modifiers.HasFlag(ModifierKeys.Control)) {
                //Title = e.Delta.ToString();
                e.Handled = true;
                if (e.Delta > 0) {
                    mainfontsize += 2;
                    if (mainfontsize > 58) mainfontsize = 58;
                }
                else {
                    mainfontsize -= 2;
                    if (mainfontsize < 8) mainfontsize = 8;
                }
                setFontsizeRegistry(mainfontsize);
            }
            else {
                e.Handled = true;
                if (e.Delta > 0) {
                    mycolortextbox.setPosition(+1);
                }
                else {
                    mycolortextbox.setPosition(-1);
                }
            }
        }

        private void clearFontMenues(object sender) {
            mnFont8pg.IsChecked = false;
            mnFont10pg.IsChecked = false;
            mnFont12pg.IsChecked = false;
            mnFont14pg.IsChecked = false;
            mnFont16pg.IsChecked = false;
            mnFont18pg.IsChecked = false;
            mnFont20pg.IsChecked = false;
            mnFont24pg.IsChecked = false;
            mnFont28pg.IsChecked = false;

            mnFont30pg.IsChecked = false;
            mnFont32pg.IsChecked = false;
            mnFont34pg.IsChecked = false;
            mnFont36pg.IsChecked = false;
            mnFont38pg.IsChecked = false;
            mnFont40pg.IsChecked = false;
            mnFont42pg.IsChecked = false;
            mnFont44pg.IsChecked = false;
            mnFont46pg.IsChecked = false;
            mnFont48pg.IsChecked = false;
            mnFont50pg.IsChecked = false;
            mnFont52pg.IsChecked = false;
            mnFont54pg.IsChecked = false;
            mnFont56pg.IsChecked = false;
            mnFont58pg.IsChecked = false;
            MenuItem mnItem = (MenuItem)sender;
            mnItem.IsChecked = true;
        }



        private void setFontsizeRegistry(int fs) {
            if (fs == 8) {
                mnFont8pg.IsChecked = true;
                clearFontMenues(mnFont8pg);
                setFontsize(8);
            }
            if (fs == 10) {
                mnFont10pg.IsChecked = true;
                clearFontMenues(mnFont10pg);
                setFontsize(10);
            }
            if (fs == 12) {
                mnFont12pg.IsChecked = true;
                clearFontMenues(mnFont12pg);
                setFontsize(12);
            }
            if (fs == 14) {
                mnFont14pg.IsChecked = true;
                clearFontMenues(mnFont14pg);
                setFontsize(14);
            }
            if (fs == 16) {
                mnFont16pg.IsChecked = true;
                clearFontMenues(mnFont16pg);
                setFontsize(16);
            }
            if (fs == 18) {
                mnFont18pg.IsChecked = true;
                clearFontMenues(mnFont18pg);
                setFontsize(18);
            }
            if (fs == 20) {
                mnFont20pg.IsChecked = true;
                clearFontMenues(mnFont20pg);
                setFontsize(20);
            }
            if (fs == 24) {
                mnFont24pg.IsChecked = true;
                clearFontMenues(mnFont24pg);
                setFontsize(24);
            }
            if (fs == 28) {
                mnFont28pg.IsChecked = true;
                clearFontMenues(mnFont28pg);
                setFontsize(28);
            }
            if (fs == 30) {
                mnFont30pg.IsChecked = true;
                clearFontMenues(mnFont30pg);
                setFontsize(30);
            }
            if (fs == 32) {
                mnFont32pg.IsChecked = true;
                clearFontMenues(mnFont32pg);
                setFontsize(32);
            }
            if (fs == 34) {
                mnFont34pg.IsChecked = true;
                clearFontMenues(mnFont34pg);
                setFontsize(34);
            }
            if (fs == 36) {
                mnFont36pg.IsChecked = true;
                clearFontMenues(mnFont36pg);
                setFontsize(36);
            }
            if (fs == 38) {
                mnFont38pg.IsChecked = true;
                clearFontMenues(mnFont38pg);
                setFontsize(38);
            }
            if (fs == 40) {
                mnFont40pg.IsChecked = true;
                clearFontMenues(mnFont40pg);
                setFontsize(40);
            }
            if (fs == 42) {
                mnFont42pg.IsChecked = true;
                clearFontMenues(mnFont42pg);
                setFontsize(42);
            }
            if (fs == 44) {
                mnFont44pg.IsChecked = true;
                clearFontMenues(mnFont44pg);
                setFontsize(44);
            }
            if (fs == 46) {
                mnFont46pg.IsChecked = true;
                clearFontMenues(mnFont46pg);
                setFontsize(46);
            }
            if (fs == 48) {
                mnFont48pg.IsChecked = true;
                clearFontMenues(mnFont48pg);
                setFontsize(48);
            }
            if (fs == 50) {
                mnFont50pg.IsChecked = true;
                clearFontMenues(mnFont50pg);
                setFontsize(50);
            }
            if (fs == 52) {
                mnFont52pg.IsChecked = true;
                clearFontMenues(mnFont42pg);
                setFontsize(52);
            }
            if (fs == 54) {
                mnFont54pg.IsChecked = true;
                clearFontMenues(mnFont44pg);
                setFontsize(54);
            }
            if (fs == 56) {
                mnFont56pg.IsChecked = true;
                clearFontMenues(mnFont46pg);
                setFontsize(56);
            }
            if (fs == 58) {
                mnFont58pg.IsChecked = true;
                clearFontMenues(mnFont48pg);
                setFontsize(58);
            }
        }




        private void setFontsize(int size) {
            this.mainfontsize = size;
            Basis.WriteRegInt(SingVar.C_REG_ADR, "fontcolorsize", size);

            mainMenu.FontSize = size;
            mycolortextbox.setFontsize(size);
            //  mycolortextbox2.InvalidateVisual();
        }

        private void setTabsizeMenues(MenuItem mn) {
            mnSize05.IsChecked = false;
            mnSize10.IsChecked = false;
            mnSize15.IsChecked = false;
            mnSize20.IsChecked = false;
            mnSize25.IsChecked = false;
            mnSize30.IsChecked = false;
            mn.IsChecked = true;
        }

        private void mnSize05_Click(Object sender, RoutedEventArgs e) {
            mycolortextbox.setTabsize(0.5);
            Basis.WriteRegString(SingVar.C_REG_ADR, "tabsize", "0.5");
            setTabsizeMenues((MenuItem)sender);
        }

        private void mnSize10_Click(Object sender, RoutedEventArgs e) {
            mycolortextbox.setTabsize(1.0);
            Basis.WriteRegString(SingVar.C_REG_ADR, "tabsize", "1.0");
            setTabsizeMenues((MenuItem)sender);
        }

        private void mnSize15_Click(Object sender, RoutedEventArgs e) {
            mycolortextbox.setTabsize(1.5);
            Basis.WriteRegString(SingVar.C_REG_ADR, "tabsize", "1.5");
            setTabsizeMenues((MenuItem)sender);
        }

        private void mnSize20_Click(Object sender, RoutedEventArgs e) {
            mycolortextbox.setTabsize(2.0);
            Basis.WriteRegString(SingVar.C_REG_ADR, "tabsize", "2.0");
            setTabsizeMenues((MenuItem)sender);
        }

        private void mnSize25_Click(Object sender, RoutedEventArgs e) {
            mycolortextbox.setTabsize(2.5);
            Basis.WriteRegString(SingVar.C_REG_ADR, "tabsize", "2.5");
            setTabsizeMenues((MenuItem)sender);
        }

        private void mnSize30_Click(Object sender, RoutedEventArgs e) {
            mycolortextbox.setTabsize(3.0);
            Basis.WriteRegString(SingVar.C_REG_ADR, "tabsize", "3.0");
            setTabsizeMenues((MenuItem)sender);
        }



        private void mnFont_Click(Object sender, RoutedEventArgs e) {
            MenuItem mn = (MenuItem)sender;
            clearFontMenues(sender);
            setFontsize(Convert.ToInt32(mn.Tag));

        }


        private void Window_Closing(Object sender, System.ComponentModel.CancelEventArgs e) {
            Basis.writeWindowPosition2Registry(this, SingVar.C_REG_ADR, dialogname);
            // e.Cancel
            parentColor.deleteColorDialog();
        }

    }
}
